@@ -10,6 +10,9 @@ sentry_wechat.models
 
 import json
 import requests
+from datetime import datetime
+from pytz import timezone
+
 from sentry.plugins.bases.notify import NotificationPlugin
 import sentry_wechat
 from django import forms
@@ -60,13 +63,14 @@ class WechatPlugin(NotificationPlugin):
 
         if self.should_notify(group, event):
             self.logger.info('send msg to wechat robot yes')
-            self.post_process(group, event, *args, **kwargs)
+            self.post_base_process(group, event, *args, **kwargs)
+            self.post_main_process(group, event, *args, **kwargs)
 
         else:
             self.logger.info('send msg to wechat robot no')
             return None
 
-    def post_process(self, group, event, *args, **kwargs):
+    def post_base_process(self, group, event, *args, **kwargs):
         """
         Process error.
         """
@@ -82,6 +86,7 @@ class WechatPlugin(NotificationPlugin):
                         {
                             "title" : title,
                             "url" : url,
+                            "description" : description,
                             "picurl" : "https://i.loli.net/2020/04/28/xZqCELKHhBSeY9t.png"
                         }
                     ]
@@ -94,6 +99,14 @@ class WechatPlugin(NotificationPlugin):
             data=json.dumps(data)
         )
 
+    def post_main_process(self, group, event, *args, **kwargs):
+        """
+        Process error.
+        """
+        send_url = self.get_webhook_urls(group.project)
+        description = event.title or event.message
+        url="{}events/{}/".format(group.get_absolute_url(),event.event_id)
+
         main_data = {
                 "msgtype": "markdown",
                 "markdown": {
@@ -108,7 +121,7 @@ class WechatPlugin(NotificationPlugin):
                         user=event.get_tag("user"),
                         message=description,
                         culprit=event.culprit,
-                        dateCreated=event.dateCreated,
+                        dateCreated=datetime.now(timezone('Asia/Shanghai')).strftime("%Y-%m-%d %H:%M:%S"),
                         url=url,
                     )
                 }
